%% GENERATE RADS PLOTS
close all
clear all
clc

%% TIDE GAUGE
time_stockholm = ncread('OS_UH-FDD826_20170113_D.nc','time');
sla_stockholm = ncread('OS_UH-FDD826_20170113_D.nc','sea_surface_height_above_reference_level');

time_stockholm = (time_stockholm/365.25)+1700;
sla_stockholm = (squeeze(sla_stockholm)-7000)/1000;

%% LOAD DATA
load('RADS.mat')

sat_string{10} = 'SARAL'; % correcting for mistake in sat_string
%% LOG FILE
delete('log_file')
diary('log_file')
diary on

%% SELECT AREA
prompt = 'Number of area\n >>';
areas = input(prompt);

idx_map = RADS_lon<32 & RADS_lon>10 & RADS_lat > 50 & RADS_lat < 70;

figure (100)
    scatter(RADS_lon(idx_map(1:100:end)),RADS_lat(idx_map(1:100:end)),1,RADS_sat(idx_map(1:100:end)));
    plot_google_map
    title(sprintf('Select the %g area',areas));
    
disp(sprintf('Select the %g area on map',areas))
    
[sel_lon,sel_lat] = ginput(areas);

areas_lon(:,1)=round(sel_lon,1)-0.5;
areas_lon(:,2)=round(sel_lon,1)+0.5;

areas_lat(:,1)=round(sel_lat,1)-0.2;
areas_lat(:,2)=round(sel_lat,1)+0.2;

areas_lon
areas_lat

lat_bound = [min(RADS_lat) max(RADS_lat)];
lon_bound = [min(RADS_lon) max(RADS_lon)];
time_span = [min(RADS_time) max(RADS_time)];

%% CHOOSE TIME and LIMITS
time_lim = time_span;
limits = [-1 1];

%% SELECT ALTIMETERS

prompt = 'Choose altimeters (in [] - comma separated):\n 1=Envisat, 2=Jason2, 3=Jason1, 4=Geosat, 5=ERS-2, 6=GFO, 7=ERS-1, 8=Cryosat, 9=TOPEX, 10=SARAL, 11=Poseidon \n >>';

altimeters_wanted = input(prompt);

idx_alti = ismember(RADS_sat,altimeters_wanted);

st=1; %running variable

%% PLOTTING RADS FOR SELECTED AREAS

%% MAKING TOP-lists
for a=1:areas;

area_lat = areas_lat(a,:);
area_lon = areas_lon(a,:);

idx_area_time = RADS_lat>area_lat(1) & RADS_lat<area_lat(2)...
           & RADS_lon>area_lon(1) & RADS_lon<area_lon(2)...
           & RADS_time>time_lim(1) & RADS_time<time_lim(2);
       
idx_lim = RADS_SLA>limits(1) & RADS_SLA<limits(2);

idx = (idx_alti+idx_area_time+idx_lim == 3);
idx_l = (idx_alti+idx_area_time+~idx_lim == 3);

RADS_timeid = RADS_time(idx);
RADS_SLAid = RADS_SLA(idx);

fprintf('\n\nAREA %g (lat %g - %g, lon %g - %g)\n',a,area_lat(1),area_lat(2),area_lon(1),area_lon(2))

fprintf('\nAltimeters: ')
fprintf('%s\t',sat_string{altimeters_wanted})
fprintf('\nNumber of points in area/time %g \n', sum(idx_area_time));
fprintf('Number of points out of limit: %g \n \n', sum(idx_l));

Rt = RADS_time(idx_l);
Rs = RADS_SLA(idx_l);
Rsat = RADS_sat(idx_l);

if isempty(Rs)==0;
for n=1:length(Rs)
fprintf('Time: %f SLA: %g Altimeter: %s \n', Rt(n),Rs(n),sat_string{Rsat(n)});
end
end

[RADS_SLA_sort,idx_ss]=sort(RADS_SLAid,'descend');
RADS_time_ss = RADS_timeid(idx_ss);

fprintf('\ntop 20 high \t\t\t\t top 20 low\n')
for n=1:20
    fprintf('Time: %f SLA: %g \t\t Time: %f SLA: %g\n', RADS_time_ss(n),RADS_SLA_sort(n),RADS_time_ss(end-(n-1)),RADS_SLA_sort(end-(n-1)));
end
%% MAKING PLOTS

figure (a)
subplot(2,4,[1 3])

for is = 1:length(altimeters_wanted);
idx_s = 0;
idx_s = find(RADS_sat(idx)==altimeters_wanted(is));
if isempty(idx_s) == 0
plot(RADS_timeid(idx_s),RADS_SLAid(idx_s),'color',sat_colors(altimeters_wanted(is),:),'marker','.','LineStyle','-')
else
altimeters_wanted(is) = NaN;
end
hold on
end

altimeters_wanted(isnan(altimeters_wanted))=[];

ylim(limits)
xlim(time_lim)
legend(sat_string(altimeters_wanted))
title(sprintf('Area %g, lat %g - %g, lon %g - %g',a,area_lat(1),area_lat(2),area_lon(1),area_lon(2)));

subplot(2,4,[5 7])
plot(time_stockholm,sla_stockholm);
xlim(time_lim)
ylim(limits)
title('Stockholm Tide Gauge')

map1=subplot(2,4,4);
scatter(RADS_lon(idx),RADS_lat(idx),2,RADS_sat(idx))
plot_google_map
colormap(map1,sat_colors(altimeters_wanted,:));

map2=subplot(2,4,8);
scatter(RADS_lon(idx),RADS_lat(idx),2,RADS_SLA(idx))
plot_google_map
colormap(map2,parula);
caxis(map2,limits)
colorbar

RADS_SLA_comb(st:(st-1)+length(RADS_SLA(idx))) = RADS_SLA(idx);
RADS_lat_comb(st:(st-1)+length(RADS_SLA(idx))) = RADS_lat(idx);
RADS_lon_comb(st:(st-1)+length(RADS_SLA(idx))) = RADS_lon(idx);

st = st+length(RADS_SLA(idx));
end

%% PLOT AREAS ON MAP
figure (101)
    scatter(RADS_lon_comb,RADS_lat_comb,1,RADS_SLA_comb);
    plot_google_map
    title(sprintf('The selected %g area',areas));
    
diary off